.. _charge:

Charges
=======

.. sectionauthor:: Matt Swain <m.swain@me.com>

This page gives details on dealing with charges in molecules.


Acid reionization
-----------------

- Ensure the strongest acid groups ionize first in partially ionized molecules.

Neutralization
--------------

- Attempt to neutralize charges by adding and/or removing hydrogens where possible.
- Not always possible to produce a neutral molecule.
